.. _api:

API
===

This page contains auto-generated documentation from the bidict source code.

bidict
------

.. automodule:: bidict
    :members:
    :member-order: bysource
    :special-members:
    :show-inheritance:
    :undoc-members:
    :exclude-members: __abstractmethods__,__dict__,__module__,__weakref__
    :inherited-members:


.. autodata:: bidict.RAISE

.. autodata:: bidict.OVERWRITE

.. autodata:: bidict.IGNORE


bidict.compat
-------------

.. automodule:: bidict.compat
    :members:
